yakumo.neutron.v2.metering.label

Package yakumo :: Package neutron :: Package v2 :: Package metering :: Module label |
[hide private]
[frames] | no frames]

# Source Code for Module yakumo.neutron.v2.metering.label

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Resource class and its manager for metering labels for Networking v2 API
    18  """
    19
    20  from yakumo import base
    21  from yakumo.constant import UNDEF
    22  from yakumo import mapper
    23  from yakumo import utils
    24
    25
    26  ATTRIBUTE_MAPPING = [
    27      ('id', 'id', mapper.Noop),
    28      ('name', 'name', mapper.Noop),
    29      ('description', 'description', mapper.Noop),
    30      ('project', 'tenant_id', mapper.Resource('project')),
    31  ]
    32
    33
    34 -class Resource(base.Resource):
    35      """Resource class for metering labels for Networking v2 API"""
    36
    37
    38 -class Manager(base.Manager):
    39      """Manager class for metering labels for Networking v2 API"""
    40
    41      resource_class = Resource
    42      service_type = 'network'
    43      _attr_mapping = ATTRIBUTE_MAPPING
    44      _hidden_methods = ["update"]
    45      _json_resource_key = 'metering_label'
    46      _json_resources_key = 'metering_labels'
    47      _url_resource_path = '/v2.0/metering/metering-labels'
    48
    49 -    def create(self, name=UNDEF, description=UNDEF):
    50          """
    51          Create a LB member for a pool
    52
    53          :param name=: Label name (str)
    54          :param description=: Description (str)
    55          """
    56          return super(Manager, self).create(name=name,
    57                                             description=description)
    58